@@ -19,27 +19,27 @@ Generate a JSON object with the following structure:
       "start_line": <START_LINE_NUMBER>,
       "end_line": <END_LINE_NUMBER>,
       "side": "LEFT|RIGHT",
-      "file_name": "<FULL_FILE_PATH>",
       "sentiment": "positive|negative|neutral",
       "severity_level": <1_TO_10>
     }}
   ]
 }}
 
-Guidelines:
+## Guidelines:
 - Provide actionable feedback with specific file paths and line numbers
 - Use markdown for code snippets
 - Merge duplicate feedback
 - Examine: syntax/logic errors, loops, null values, resource leaks, race conditions, integration/performance issues, security vulnerabilities
 - If no feedback: {{"review": []}}
 
-Review Focus:
+## Review Focus:
 1. removals ('<->') are the original code, just identify if anything causes problem because of removal
 2. Provide feedback for additions ('<+>') as this are the new code changes.
 3. Consider impact of changes on code
 4. Note unchanged lines ('<.>')
+5. Make sure to follow the additional instruction.
 
-Patch Data Format:
+## Patch Data Format:
 - First column: Original file line numbers
 - Second column: New file line numbers
 - Third column: Change type
@@ -48,12 +48,16 @@ Patch Data Format:
   '<.>': Unchanged line (both columns)
 - Remaining columns: Code content
 
-Field Guidelines:
+## Field Guidelines:
 - "fixed_code": Provide corrected code only for additions, ensuring changes are between start_line and end_line.
 - "start_line" and "end_line": Actual line numbers in the new file where the change begins and ends
 - "severity_level": Score from 1 (least severe) to 10 (most critical)
 
-INFORMATION:
+## Additional Instructions:
+Mark items which fall under following as critical and severity score of 10.
+{CUSTOM_PROMPT}
+
+## INFORMATION:
 
 Pull Request Title: {PULL_REQUEST_TITLE}
 Pull Request Description: {PULL_REQUEST_DESC}
@@ -79,27 +83,26 @@ Generate a JSON object with the following structure:
       "start_line": <START_LINE_NUMBER>,
       "end_line": <END_LINE_NUMBER>,
       "side": "LEFT|RIGHT",
-      "file_name": "<FULL_FILE_PATH>",
       "sentiment": "positive|negative|neutral",
       "severity_level": <1_TO_10>
     }}
   ]
 }}
 
-Guidelines:
+## Guidelines:
 - Provide actionable feedback with specific file paths and line numbers
 - Use markdown for code snippets
 - Merge duplicate feedback
 - Examine: syntax/logic errors, loops, null values, resource leaks, race conditions, integration/performance issues, security vulnerabilities
 - If no feedback: {{"review": []}}
 
-Review Focus:
+## Review Focus:
 1. removals ('<->') are the original code, just identify if anything causes problem because of removal
 2. Provide feedback for additions ('<+>') as this are the new code changes.
 3. Consider impact of changes on code
 4. Note unchanged lines ('<.>')
 
-Patch Data Format:
+## Patch Data Format:
 - First column: Original file line numbers
 - Second column: New file line numbers
 - Third column: Change type
@@ -108,15 +111,16 @@ Patch Data Format:
   '<.>': Unchanged line (both columns)
 - Remaining columns: Code content
 
-Field Guidelines:
+## Field Guidelines:
 - "fixed_code": Provide corrected code only for additions, ensuring changes are between start_line and end_line.
 - "start_line" and "end_line": Actual line numbers in the new file where the change begins and ends
 - "severity_level": Score from 1 (least severe) to 10 (most critical)
 
-INFORMATION:
+## Additional Instructions:
+Mark items which fall under following as critical and severity score of 10.
+{CUSTOM_PROMPT}
 
-Pull Request Title: {PULL_REQUEST_TITLE}
-Pull Request Description: {PULL_REQUEST_DESC}
+## INFORMATION:
 
 File PATCH:
 ```{FILE_PATCH}```
